@@ -115,7 +115,7 @@ class ImageNode(template.Node):
         if not hasattr(image, 'get_rendition'):
             raise ValueError("image tag expected an Image object, got %r" % image)
 
-        if color_expr:
+        if color_expr and re.search(r'^#(?:[0-9a-fA-F]{3}){1,2}$', color_expr):
             logger.debug('Change bg color with %s' % str(color_expr))
             tag = 'bgcolor-%s' % color_expr.replace('#', '')
             self.filter_spec = tag + '|' + self.filter_spec
