@@ -121,6 +121,14 @@ URL_BUCKET_FILE = 'https://s3-eu-west-3.amazonaws.com/' + AWS_STORAGE_BUCKET_NAM
 S3DIRECT_REGION = 'eu-west-3'
 AWS_S3_FILE_OVERWRITE = False
 
+# Emails
+
+EMAIL_HOST = 'smtp.sendgrid.net'
+EMAIL_HOST_USER = 'apikey'
+EMAIL_HOST_PASSWORD = SENDGRID_SK
+EMAIL_PORT = 587
+EMAIL_USE_TLS = True
+
 # Wagtail
 
 WAGTAIL_SITE_NAME = SITE_NAME
